@@ -5,6 +5,7 @@ use strict;
 use Firefox::Marionette::Response();
 use Firefox::Marionette::Element();
 use Firefox::Marionette::Cookie();
+use Firefox::Marionette::Window::Rect();
 use Firefox::Marionette::Element::Rect();
 use Firefox::Marionette::Timeouts();
 use Firefox::Marionette::Capabilities();
@@ -27,7 +28,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -107,6 +108,7 @@ sub _launch_unix {
             exec {$binary} $binary, @arguments
               or Carp::croak("Failed to exec '$binary':$EXTENDED_OS_ERROR");
         } or do {
+            chomp $EVAL_ERROR;
             warn "$EVAL_ERROR\n";
         };
         exit 1;
@@ -375,6 +377,78 @@ sub add_cookie {
     return $self;
 }
 
+sub is_selected {
+    my ( $self, $element ) = @_;
+    if (
+        !(
+               ( ref $element )
+            && ( $element->isa('Firefox::Marionette::Element') )
+        )
+      )
+    {
+        Carp::croak(
+'is_selected method requires a Firefox::Marionette::Element parameter'
+        );
+    }
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [
+            _COMMAND(), $message_id,
+            'WebDriver:IsElementSelected', { id => $element->uuid() }
+        ]
+    );
+    my $response = $self->_get_response($message_id);
+    return $response->result()->{value} ? 1 : 0;
+}
+
+sub is_enabled {
+    my ( $self, $element ) = @_;
+    if (
+        !(
+               ( ref $element )
+            && ( $element->isa('Firefox::Marionette::Element') )
+        )
+      )
+    {
+        Carp::croak(
+'is_enabled method requires a Firefox::Marionette::Element parameter'
+        );
+    }
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [
+            _COMMAND(), $message_id,
+            'WebDriver:IsElementEnabled', { id => $element->uuid() }
+        ]
+    );
+    my $response = $self->_get_response($message_id);
+    return $response->result()->{value} ? 1 : 0;
+}
+
+sub is_displayed {
+    my ( $self, $element ) = @_;
+    if (
+        !(
+               ( ref $element )
+            && ( $element->isa('Firefox::Marionette::Element') )
+        )
+      )
+    {
+        Carp::croak(
+'is_displayed method requires a Firefox::Marionette::Element parameter'
+        );
+    }
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [
+            _COMMAND(), $message_id,
+            'WebDriver:IsElementDisplayed', { id => $element->uuid() }
+        ]
+    );
+    my $response = $self->_get_response($message_id);
+    return $response->result()->{value} ? 1 : 0;
+}
+
 sub send_keys {
     my ( $self, $element, $text ) = @_;
     if (
@@ -497,6 +571,39 @@ sub tag_name {
     return $response->result()->{value};
 }
 
+sub window_rect {
+    my ( $self, $new ) = @_;
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [ _COMMAND(), $message_id, 'WebDriver:GetWindowRect' ] );
+    my $response = $self->_get_response($message_id);
+    my $old      = Firefox::Marionette::Window::Rect->new(
+        pos_x  => $response->result()->{x},
+        pos_y  => $response->result()->{y},
+        width  => $response->result()->{width},
+        height => $response->result()->{height},
+        state  => $response->result()->{state},
+    );
+    if ( defined $new ) {
+        $message_id = $self->_new_message_id();
+        $self->_send_request(
+            [
+                _COMMAND(),
+                $message_id,
+                'WebDriver:SetWindowRect',
+                {
+                    x      => $new->pos_x(),
+                    y      => $new->pos_y(),
+                    width  => $new->width(),
+                    height => $new->height()
+                }
+            ]
+        );
+        $self->_get_response($message_id);
+    }
+    return $old;
+}
+
 sub rect {
     my ( $self, $element ) = @_;
     if (
@@ -595,16 +702,33 @@ sub click {
 }
 
 sub timeouts {
-    my ($self) = @_;
+    my ( $self, $new ) = @_;
     my $message_id = $self->_new_message_id();
     $self->_send_request(
         [ _COMMAND(), $message_id, 'WebDriver:GetTimeouts' ] );
     my $response = $self->_get_response($message_id);
-    return Firefox::Marionette::Timeouts->new(
+    my $old      = Firefox::Marionette::Timeouts->new(
         page_load => $response->result()->{pageLoad},
         script    => $response->result()->{script},
         implicit  => $response->result()->{implicit}
     );
+    if ( defined $new ) {
+        $message_id = $self->_new_message_id();
+        $self->_send_request(
+            [
+                _COMMAND(),
+                $message_id,
+                'WebDriver:SetTimeouts',
+                {
+                    pageLoad => $new->page_load(),
+                    script   => $new->script(),
+                    implicit => $new->implicit()
+                }
+            ]
+        );
+        $self->_get_response($message_id);
+    }
+    return $old;
 }
 
 sub active_element {
@@ -970,6 +1094,15 @@ sub switch_to_parent_frame {
     return $self;
 }
 
+sub window_type {
+    my ($self) = @_;
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [ _COMMAND(), $message_id, 'WebDriver:GetWindowType' ] );
+    my $response = $self->_get_response($message_id);
+    return $response->result()->{value};
+}
+
 sub switch_to_frame {
     my ( $self, $element ) = @_;
     my $message_id = $self->_new_message_id();
@@ -1037,11 +1170,11 @@ my $x = <<'_DOC_';
 #  "WebDriver:GetTitle": GeckoDriver.prototype.getTitle,
 #  "WebDriver:GetWindowHandle": GeckoDriver.prototype.getWindowHandle,
 #  "WebDriver:GetWindowHandles": GeckoDriver.prototype.getWindowHandles,
-  "WebDriver:GetWindowRect": GeckoDriver.prototype.getWindowRect,
-  "WebDriver:GetWindowType": GeckoDriver.prototype.getWindowType,
-  "WebDriver:IsElementDisplayed": GeckoDriver.prototype.isElementDisplayed,
-  "WebDriver:IsElementEnabled": GeckoDriver.prototype.isElementEnabled,
-  "WebDriver:IsElementSelected": GeckoDriver.prototype.isElementSelected,
+#  "WebDriver:GetWindowRect": GeckoDriver.prototype.getWindowRect,
+#  "WebDriver:GetWindowType": GeckoDriver.prototype.getWindowType,
+#  "WebDriver:IsElementDisplayed": GeckoDriver.prototype.isElementDisplayed,
+#  "WebDriver:IsElementEnabled": GeckoDriver.prototype.isElementEnabled,
+#  "WebDriver:IsElementSelected": GeckoDriver.prototype.isElementSelected,
 #  "WebDriver:MinimizeWindow": GeckoDriver.prototype.minimizeWindow,
 #  "WebDriver:MaximizeWindow": GeckoDriver.prototype.maximizeWindow,
 #  "WebDriver:Navigate": GeckoDriver.prototype.get,
@@ -1051,13 +1184,13 @@ my $x = <<'_DOC_';
   "WebDriver:ReleaseActions": GeckoDriver.prototype.releaseActions,
 #  "WebDriver:SendAlertText": GeckoDriver.prototype.sendKeysToDialog,
   "WebDriver:SetScreenOrientation": GeckoDriver.prototype.setScreenOrientation
-  "WebDriver:SetTimeouts": GeckoDriver.prototype.setTimeouts,
-  "WebDriver:SetWindowRect": GeckoDriver.prototype.setWindowRect,
+#  "WebDriver:SetTimeouts": GeckoDriver.prototype.setTimeouts,
+#  "WebDriver:SetWindowRect": GeckoDriver.prototype.setWindowRect,
 #  "WebDriver:SwitchToFrame": GeckoDriver.prototype.switchToFrame,
   "WebDriver:SwitchToParentFrame": GeckoDriver.prototype.switchToParentFrame,
   "WebDriver:SwitchToShadowRoot": GeckoDriver.prototype.switchToShadowRoot,
   "WebDriver:SwitchToWindow": GeckoDriver.prototype.switchToWindow,
-  "WebDriver:TakeScreenshot": GeckoDriver.prototype.takeScreenshot,
+#  "WebDriver:TakeScreenshot": GeckoDriver.prototype.takeScreenshot,
 _DOC_
 
 sub marionette_protocol {
@@ -1155,7 +1288,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -1164,7 +1297,7 @@ Version 0.07
 
     my $firefox = Firefox::Marionette->new()->go('https://metacpan.org/');
 
-    $firefox->find_element('//input[@id="search-input"]')->send('Test::More');
+    $firefox->find_element('//input[@id="search-input"]')->send_keys('Test::More');
 
     my $file_handle = $firefox->selfie(highlights => [ $firefox->find_element('//button[@name="lucky"]') ])
 
@@ -1282,6 +1415,18 @@ returns the contents of the cookie jar in scalar or list context.
 
 accepts an L<element|Firefox::Marionette::Element> as the first parameter and a string as the second parameter.  It sends the string to the specified L<element|Firefox::Marionette::Element> in the current page, such as filling out a text box. This method returns L<itself|Firefox::Marionette> to aid in chaining methods.
 
+=head2 is_displayed
+
+accepts an L<element|Firefox::Marionette::Element> as the first parameter.  This method returns true or false depending on if the element is displayed.
+
+=head2 is_enabled
+
+accepts an L<element|Firefox::Marionette::Element> as the first parameter.  This method returns true or false depending on if the element is enabled.
+
+=head2 is_selected
+
+accepts an L<element|Firefox::Marionette::Element> as the first parameter.  This method returns true or false depending on if the element is selected.
+
 =head2 active_element
 
 returns the active element of the current browsing context's document element, if the document element is non-null.
@@ -1372,6 +1517,10 @@ The parameters after the L<element|Firefox::Marionette::Element> parameter are t
 
 accepts a L<Firefox::Marionette::Element|Firefox::Marionette::Element> object as the first parameter and returns the relevant tag name.  For example 'a' or 'input'.
 
+=head2 window_rect
+
+accepts an optional <position and size|Firefox::Marionette::Window::Rect> as a parameter, sets the current browser window to that position and size and returns the previous L<position, size and state|Firefox::Marionette::Window::Rect> of the browser window.  If no parameter is supplied, it returns the current  L<position, size and state|Firefox::Marionette::Window::Rect> of the browser window.
+
 =head2 rect
 
 accepts a L<element|Firefox::Marionette::Element> as the first parameter and returns the current L<position and size|Firefox::Marionette::Element::Rect> of the L<element|Firefox::Marionette::Element>
@@ -1396,6 +1545,10 @@ returns the current L<timeouts|Firefox::Marionette::Timeouts> for page loading,
 
 creates a new WebDriver session.  It is expected that the caller performs the necessary checks on the requested capabilities to be WebDriver conforming.  The WebDriver service offered by Marionette does not match or negotiate capabilities beyond type and bounds checks.
 
+=head2 window_type
+
+returns the current window's type.  This should be 'navigator:browser'.
+
 =head2 window_handle
 
 returns the current window's handle. On desktop this typically corresponds to the currently selected tab.  returns an opaque server-assigned identifier to this window that uniquely identifies it within this Marionette instance.  This can be used to switch to this window at a later point.
@@ -1442,6 +1595,14 @@ Marionette will stop accepting new connections before ending the current session
  
 The module was unable to even create a socket.  Something is seriously wrong with your environment
  
+=item C<< Failed to send request to firefox: %s >>
+ 
+The module was unable to perform a syswrite on the socket connected to firefox.
+ 
+=item C<< Failed to correctly determined the Firefox process id through the initial connection capabilities >>
+ 
+The module was found that firefox is reporting through it's L<Capabilities|Firefox::Marionette::Capabilities#moz_process_id> object a different process id than this module was using.  This is probably a bug in this module's logic.  Please report as described in the BUGS AND LIMITATIONS section below.
+ 
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
