@@ -3,7 +3,7 @@ package Firefox::Marionette::Element;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ( $class, $browser, $parameters ) = @_;
@@ -74,6 +74,21 @@ sub selfie {
     return $self->browser()->selfie( $self, %extra );
 }
 
+sub is_enabled {
+    my ($self) = @_;
+    return $self->browser()->is_enabled($self);
+}
+
+sub is_selected {
+    my ($self) = @_;
+    return $self->browser()->is_selected($self);
+}
+
+sub is_displayed {
+    my ($self) = @_;
+    return $self->browser()->is_displayed($self);
+}
+
 1;    # Magic true value required at end of module
 __END__
 
@@ -83,7 +98,7 @@ Firefox::Marionette::Element - Represents a Firefox element retrieved using the
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -168,6 +183,18 @@ accepts the following optional parameters as a hash;
 
 =back
 
+=head2 is_enabled
+
+returns true or false if the element is enabled.
+
+=head2 is_selected
+
+returns true or false if the element is selected.
+
+=head2 is_displayed
+
+returns true or false if the element is displayed.
+
 =head1 DIAGNOSTICS
 
 None.
