@@ -3,7 +3,7 @@ package Firefox::Marionette::Element::Rect;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -40,7 +40,7 @@ Firefox::Marionette::Element::Rect - Represents the box around an Element
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ Version 0.07
 
     my $firefox = Firefox::Marionette->new()->go('https://metacpan.org/');
     my $rect = $firefox->find_element('//button[@name="lucky"]')->rect();
-    say "Current height of the Lucky button " . $cookie->height();
+    say "Current height of the Lucky button " . $rect->height();
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =back
 
-This method returns a new L<cookie|Firefox::Marionette::Element::Rect> object.
+This method returns a new L<rect|Firefox::Marionette::Element::Rect> object.
  
 =head2 pos_x
 
