@@ -47,7 +47,7 @@ Firefox::Marionette::Response - Represents a Marionette protocol response
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ accepts a reference to an array as a parameter.  The four components of a Marion
 
 =back
 
-This method returns a new L<cookie|Firefox::Marionette::Response> object.
+This method returns a new L<response|Firefox::Marionette::Response> object.
  
 =head2 type
 
