@@ -3,7 +3,7 @@ package Firefox::Marionette::Window::Rect;
 use strict;
 use warnings;
 
-our $VERSION = '0.98_07';
+our $VERSION = '0.08';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -31,9 +31,9 @@ sub height {
     return $self->{height};
 }
 
-sub wstate {
+sub state {
     my ($self) = @_;
-    return $self->{wstate};
+    return $self->{state};
 }
 
 1;    # Magic true value required at end of module
@@ -45,7 +45,7 @@ Firefox::Marionette::Window::Rect - Represents the browser window's shape and si
 
 =head1 VERSION
 
-Version 0.98_07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -68,15 +68,15 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =over 4
 
-=item * pos_x - the X position of the window.  This function will return undef for older Firefoxen.
+=item * pos_x - the X position of the window
 
-=item * pos_y - the Y position of the window.  This function will return undef for older Firefoxen.
+=item * pos_y - the Y position of the window
 
 =item * height - the height of the window
 
 =item * width - the width of the window
 
-=item * wstate - the state of the window as a scalar string.  This function will return undef for Firefox versions less than 57
+=item * state - the state of the window as a scalar string
 
 =back
 
@@ -98,7 +98,7 @@ returns the height of the window
 
 returns the width of the window
 
-=head2 wstate
+=head2 state
 
 returns a scalar representing the state of the window. For example 'maximized'.
 
@@ -132,7 +132,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2018, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
